#!/bin/bash

# Specify location of TBB
export TBBROOT=${PREFIX}

##############################################################################
# OpenImageDenoise
##############################################################################

cd ${SRC_DIR}/oidn

if [ ! -d build ]; then
    mkdir build
fi
cd build

echo "Configuring oidn..."
cmake \
    -G "${CMAKE_GENERATOR}" \
    -DCMAKE_OSX_SYSROOT="${CONDA_BUILD_SYSROOT}" \
    -DCMAKE_AR="${AR}" \
    -DCMAKE_INSTALL_PREFIX="${PREFIX}" \
    -DCMAKE_BUILD_TYPE=Release \
    -DISPC_EXECUTABLE="${SRC_DIR}/ispc/bin/ispc" \
    -DOIDN_APPS=OFF \
    ..

echo "Building oidn..."
cmake --build . --parallel ${CPU_COUNT}

echo "Installing oidn..."
make install

##############################################################################
# Embree
##############################################################################

cd ${SRC_DIR}/embree

# Patch the Embree CMake script to make it find Conda's version of the 'objdump' tool on Linux.
git apply ${RECIPE_DIR}/patches/0001-Use-OBJDUMP-environment-variable.patch

if [ ! -d build ]; then
    mkdir build
fi
cd build

echo "Configuring embree..."
cmake \
    -G "${CMAKE_GENERATOR}" \
    -DCMAKE_OSX_SYSROOT="${CONDA_BUILD_SYSROOT}" \
    -DCMAKE_INSTALL_PREFIX="${PREFIX}" \
    -DCMAKE_BUILD_TYPE=Release \
    -DCMAKE_AR="${AR}" \
    -DEMBREE_IGNORE_CMAKE_CXX_FLAGS=OFF \
    -DEMBREE_LIBRARY_NAME=embree_ovito \
    -DCMAKE_INSTALL_LIBDIR=lib \
    -DEMBREE_ISPC_EXECUTABLE="${SRC_DIR}/ispc/bin/ispc" \
    -DEMBREE_TUTORIALS=OFF \
    -DEMBREE_MAX_ISA=AVX2 \
    ..

echo "Building embree..."
cmake --build . --parallel ${CPU_COUNT}

echo "Installing embree..."
make install

##############################################################################
# rkcommon
##############################################################################

cd ${SRC_DIR}/rkcommon
if [ ! -d build ]; then
    mkdir build
fi
cd build

echo "Configuring rkcommon..."
cmake \
    -G "${CMAKE_GENERATOR}" \
    -DCMAKE_OSX_SYSROOT="${CONDA_BUILD_SYSROOT}" \
    -DCMAKE_INSTALL_PREFIX="${PREFIX}" \
    -DCMAKE_BUILD_TYPE=Release \
    -DCMAKE_INSTALL_LIBDIR=lib \
    ..

echo "Building rkcommon..."
cmake --build . --parallel ${CPU_COUNT}

echo "Installing rkcommon..."
make install

##############################################################################
# OpenVKL
##############################################################################

cd ${SRC_DIR}/openvkl
if [ ! -d build ]; then
    mkdir build
fi
cd build

echo "Configuring openvkl..."
cmake \
    -G "${CMAKE_GENERATOR}" \
    -DCMAKE_OSX_SYSROOT="${CONDA_BUILD_SYSROOT}" \
    -DCMAKE_AR="${AR}" \
    -DCMAKE_INSTALL_PREFIX="${PREFIX}" \
    -DCMAKE_BUILD_TYPE=Release \
    -DISPC_EXECUTABLE="${SRC_DIR}/ispc/bin/ispc" \
    -DBUILD_TESTING=OFF \
    -DBUILD_EXAMPLES=OFF \
    -DCMAKE_INSTALL_LIBDIR=lib \
    ..

echo "Building openvkl..."
cmake --build . --parallel ${CPU_COUNT}

echo "Installing openvkl..."
make install

##############################################################################
# OSPRay
##############################################################################

cd ${SRC_DIR}/ospray

if [ ! -d build ]; then
    mkdir build
fi
cd build

echo "Configuring ospray..."
cmake \
    -G "${CMAKE_GENERATOR}" \
    -DCMAKE_OSX_SYSROOT="${CONDA_BUILD_SYSROOT}" \
    -DCMAKE_AR="${AR}" \
    -DCMAKE_INSTALL_PREFIX="${PREFIX}" \
    -DCMAKE_BUILD_TYPE=Release \
    -DISPC_EXECUTABLE="${SRC_DIR}/ispc/bin/ispc" \
    -DCMAKE_INSTALL_LIBDIR=lib \
    -DOSPRAY_APPS_TESTING=OFF \
    -DOSPRAY_ENABLE_APPS=OFF \
    -DOSPRAY_BUILD_ISA=AVX2 \
    -DOSPRAY_MODULE_DENOISER=ON \
    ..

echo "Building ospray..."
cmake --build . --parallel ${CPU_COUNT}

echo "Installing ospray..."
make install

echo "Cleaning up..."
# Remove stuff we don't want in the conda package.
rm -rfv $PREFIX/share/man/man3
rm -rfv $PREFIX/uninstall.command
rm -rfv $PREFIX/bin/rkcommon_test_suite
rm -rfv $PREFIX/share/doc/embree3/readme.pdf
rm -rfv $PREFIX/share/doc/OpenImageDenoise/readme.pdf

echo "Done"
